'''
Tests for personal methods.
'''

from oceanex_py3 import personal
from oceanex_py3 import public
from . import configuration

test_config = configuration.test_config
p = personal.Personal(test_config['uid'], test_config['apikey_id'], test_config['private_key_location'])

def test_accounts():
    accounts = p.get_accounts()
    assert len(accounts) != 0

def test_buy_status_cancel():
    ''' Test with the market '''
    # create a buy order, which is really low
    _, bids, _ = public.get_orderbook('ticvet', 10)
    lowest_buy_price = bids[0].price
    for each in bids:
        if each.price < lowest_buy_price:
            lowest_buy_price = each.price

    order1 = p.new_buy_limit_order('tic', 'vet', lowest_buy_price, 101/lowest_buy_price)
    assert order1 != None
    assert order1.price == lowest_buy_price

    # create a sell order.
    asks, _, _ = public.get_orderbook('vetbtc', 10)
    highest_sell_price = asks[0].price
    for each in asks:
        if each.price > highest_sell_price:
            highest_sell_price = each.price

    order2 = p.new_sell_limit_order('vet', 'btc', highest_sell_price, 10000)
    assert order2 != None
    assert order2.price == highest_sell_price

    # check the all the order status.
    m_orders = p.orders_status([order1.identifier, order2.identifier])
    assert m_orders[0].price == order1.price
    assert m_orders[1].price == order2.price

    # cancel orders
    assert p.cancel_orders([order1.identifier, order2.identifier]) == True
    # cancel all orders
    assert p.cancel_all_orders() == True


"""
oceanex_py3
-------------

oceanex_py3 is a Python SDK to query, trade and manage funds on Oceanex.

"""
from setuptools import setup


setup(
    name='oceanex_py3',
    version='1.0.0',
    url='https://github.com/laalaguer/oceanex_py3',
    license='MIT',
    author='laalaguer',
    author_email='laalaguer@gmail.com',
    description='Query, trade and manage funds on Oceanex.',
    long_description=__doc__,
    packages=['oceanex_py3'],
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    install_requires=[
        'pytest',
        'requests',
        'pyjwt'
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)



''' Tests for public methods. '''

from oceanex_py3 import public

def test_markets():
    m = public.Market('btc', 'usdt', 'btcusdt')
    assert m in public.get_markets()

def test_orderbook():
    asks, bids, timestamp = public.get_orderbook('btcusdt', 10)

    assert len(asks) == 10
    assert len(bids) == 10
    assert type(timestamp) == int

def test_non_exist_orderbook():
    asks, bids, timestamp = public.get_orderbook('vvvusdt', 10)

    assert len(asks) == 0
    assert len(bids) == 0
    assert timestamp == 0

def test_trade():
    trades = public.get_trades('btcusdt', 20)
    assert len(trades) == 20
